module.exports = defineTest({
	description: 'retains pure annotations in class fields'
});
